@@ -221,9 +221,9 @@ set_ipc_name(const char *prefix)
 	char process_name[256];
 
 	/* The process-unique part of the IPC name has already been decided
-	 * and stored in the file ipc-test-name.
+	 * and stored in the file IPC_TEST_NAME_FILE
 	 */
-	f = fopen("ipc-test-name", "r");
+	f = fopen(IPC_TEST_NAME_FILE, "r");
 	if (f) {
 		fgets(process_name, sizeof(process_name), f);
 		fclose(f);
@@ -710,7 +710,7 @@ s1_connection_created(qb_ipcs_connection_t *c)
 	}
 
 
-	ck_assert_int_eq(max, qb_ipcs_connection_get_buffer_size(c));
+	ck_assert_int_le(max, qb_ipcs_connection_get_buffer_size(c));
 
 }
 
@@ -1598,15 +1598,18 @@ test_ipc_stress_connections(void)
 	}
 	multiple_connections = QB_FALSE;
 
-	request_server_exit();
-	verify_graceful_stop(pid);
-	qb_ipcc_disconnect(conn);
-
+	/* Re-enable logging here so we get the "Free'ing" message which allows
+	   for resources.test to clear up after us if needed */
 	qb_log_filter_ctl(QB_LOG_STDERR, QB_LOG_FILTER_CLEAR_ALL,
 			  QB_LOG_FILTER_FILE, "*", LOG_TRACE);
 	qb_log_filter_ctl(QB_LOG_STDERR, QB_LOG_FILTER_ADD,
 			  QB_LOG_FILTER_FILE, "*", LOG_TRACE);
 	qb_log_ctl(QB_LOG_STDERR, QB_LOG_CONF_ENABLED, QB_TRUE);
+
+	request_server_exit();
+	qb_ipcc_disconnect(conn);
+	verify_graceful_stop(pid);
+
 }
 
 static void
@@ -1700,7 +1703,7 @@ test_ipc_stress_test(void)
 	ck_assert(conn != NULL);
 
 	real_buf_size = qb_ipcc_get_buffer_size(conn);
-	ck_assert_int_eq(real_buf_size, max_size);
+	ck_assert_int_ge(real_buf_size, max_size);
 
 	qb_log(LOG_DEBUG, "Testing %d iterations of EVENT msg passing.", num_stress_events);
 
@@ -2113,7 +2116,7 @@ START_TEST(test_ipc_server_perms)
 }
 END_TEST
 
-START_TEST(test_ipc_dispatch_shm_native_prio_dlock)
+START_TEST(test_ipc_disp_shm_native_prio_dlock)
 {
 	pid_t server_pid, alphaclient_pid;
 	struct dispatch_data data;
@@ -2152,7 +2155,7 @@ START_TEST(test_ipc_dispatch_shm_native_prio_dlock)
 END_TEST
 
 #if HAVE_GLIB
-START_TEST(test_ipc_dispatch_shm_glib_prio_dlock)
+START_TEST(test_ipc_disp_shm_glib_prio_dlock)
 {
 	pid_t server_pid, alphaclient_pid;
 	struct dispatch_data data;
@@ -2369,9 +2372,9 @@ make_shm_suite(void)
 	add_tcase(s, tc, test_ipc_service_ref_count_shm, 9);
 	add_tcase(s, tc, test_ipc_server_perms, 7);
 	add_tcase(s, tc, test_ipc_stress_connections_shm, 3600 /* ? */);
-	add_tcase(s, tc, test_ipc_dispatch_shm_native_prio_dlock, 15);
+	add_tcase(s, tc, test_ipc_disp_shm_native_prio_dlock, 15);
 #if HAVE_GLIB
-	add_tcase(s, tc, test_ipc_dispatch_shm_glib_prio_dlock, 15);
+	add_tcase(s, tc, test_ipc_disp_shm_glib_prio_dlock, 15);
 #endif
 #ifdef HAVE_FAILURE_INJECTION
 	add_tcase(s, tc, test_ipcc_truncate_when_unlink_fails_shm, 8);
